==> NyaLib-0.11.2-sources.jar: net/danygames2014/nyalib/mixin/network/BlockMixin.java <==
package net.danygames2014.nyalib.mixin.network;

import net.danygames2014.nyalib.network.NetworkComponent;
import net.danygames2014.nyalib.network.NetworkManager;
import net.minecraft.class_17;
import net.minecraft.class_18;
import net.minecraft.class_395;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(class_17.class)
public abstract class BlockMixin {
    @SuppressWarnings({"unchecked", "ConstantValue"})
    @Inject(method = "onPlaced(Lnet/minecraft/world/World;III)V", at = @At(value = "TAIL"))
    public <T extends class_17 & NetworkComponent> void addToNetOnPlaced(class_18 world, int x, int y, int z, CallbackInfo ci) {
        if (!((Object) this instanceof class_395)) { // I hate this, I hate this, I hate this
            if ((Object) this instanceof class_17 && (Object) this instanceof NetworkComponent) {
                T component = (T) (Object) this;
                component.addToNet(world,x,y,z, component);

                //NetworkManager.addBlock(world, x, y, z, (T) (Object) this);
                //System.out.println("onPlaced BlockMixin");
            }
        }
    }

    @SuppressWarnings({"ConstantValue", "unchecked"})
    @Inject(method = "onBreak", at = @At(value = "HEAD"))
    public <T extends class_17 & NetworkComponent> void removeFromNetOnPlaced(class_18 world, int x, int y, int z, CallbackInfo ci) {
        if (!((Object) this instanceof class_395)) { // I hate this, I hate this, I hate this
            if ((Object) this instanceof class_17 && (Object) this instanceof NetworkComponent) {
                T component = (T) (Object) this;
                component.removeFromNet(world,x,y,z, component);

                //NetworkManager.removeBlock(world, x, y, z, (T) (Object) this);
                System.out.println("onBreak BlockMixin");
            }
        }
    }
}

==> NyaLib-0.13.0-sources.jar: net/danygames2014/nyalib/mixin/network/BlockMixin.java <==
package net.danygames2014.nyalib.mixin.network;

import net.danygames2014.nyalib.network.NetworkComponent;
import net.minecraft.class_17;
import net.minecraft.class_18;
import net.minecraft.class_395;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(class_17.class)
public abstract class BlockMixin {
    @SuppressWarnings({"unchecked", "ConstantValue"})
    @Inject(method = "onPlaced(Lnet/minecraft/world/World;III)V", at = @At(value = "TAIL"))
    public <T extends class_17 & NetworkComponent> void addToNetOnPlaced(class_18 world, int x, int y, int z, CallbackInfo ci) {
        if (!((Object) this instanceof class_395)) { // I hate this, I hate this, I hate this
            if ((Object) this instanceof class_17 && (Object) this instanceof NetworkComponent) {
                T component = (T) (Object) this;
                component.addToNet(world,x,y,z, component);

                //NetworkManager.addBlock(world, x, y, z, (T) (Object) this);
                //System.out.println("onPlaced BlockMixin");
            }
        }
    }

    @SuppressWarnings({"ConstantValue", "unchecked"})
    @Inject(method = "onBreak", at = @At(value = "HEAD"))
    public <T extends class_17 & NetworkComponent> void removeFromNetOnPlaced(class_18 world, int x, int y, int z, CallbackInfo ci) {
        if (!((Object) this instanceof class_395)) { // I hate this, I hate this, I hate this
            if ((Object) this instanceof class_17 && (Object) this instanceof NetworkComponent) {
                T component = (T) (Object) this;
                component.removeFromNet(world,x,y,z, component);

                //NetworkManager.removeBlock(world, x, y, z, (T) (Object) this);
                //System.out.println("onBreak BlockMixin");
            }
        }
    }
}
